@@ -10,6 +10,7 @@ from hashlib import md5
 from pathlib import Path
 from tempfile import NamedTemporaryFile
 from typing import TYPE_CHECKING
+from unittest import mock
 
 import pytest
 from click.testing import CliRunner
@@ -24,10 +25,36 @@ if TYPE_CHECKING:
     from tempfile import _TemporaryFileWrapper
     from typing import Any, Callable, Generator, Protocol, Sequence, TypedDict
 
+    from click.testing import Result
     from filelock import AcquireReturnProxy
+    from git import Actor
 
     from tests.fixtures.git_repo import RepoActions
 
+    class RunCliFn(Protocol):
+        """
+        Run the CLI with the provided arguments and a clean environment.
+
+        :param argv: The arguments to pass to the CLI.
+        :type argv: list[str] | None
+
+        :param env: The environment variables to set for the CLI.
+        :type env: dict[str, str] | None
+
+        :param invoke_kwargs: Additional arguments to pass to the invoke method.
+        :type invoke_kwargs: dict[str, Any] | None
+
+        :return: The result of the CLI invocation.
+        :rtype: Result
+        """
+
+        def __call__(
+            self,
+            argv: list[str] | None = None,
+            env: dict[str, str] | None = None,
+            invoke_kwargs: dict[str, Any] | None = None,
+        ) -> Result: ...
+
     class MakeCommitObjFn(Protocol):
         def __call__(self, message: str) -> Commit: ...
 
@@ -169,6 +196,25 @@ def cli_runner() -> CliRunner:
     return CliRunner(mix_stderr=False)
 
 
+@pytest.fixture(scope="session")
+def run_cli(clean_os_environment: dict[str, str]) -> RunCliFn:
+    def _run_cli(
+        argv: list[str] | None = None,
+        env: dict[str, str] | None = None,
+        invoke_kwargs: dict[str, Any] | None = None,
+    ) -> Result:
+        from semantic_release.cli.commands.main import main
+
+        cli_runner = CliRunner(mix_stderr=False)
+        env_vars = {**clean_os_environment, **(env or {})}
+
+        with mock.patch.dict(os.environ, env_vars, clear=True):
+            # run the CLI with the provided arguments
+            return cli_runner.invoke(main, args=(argv or []), **(invoke_kwargs or {}))
+
+    return _run_cli
+
+
 @pytest.fixture(scope="session")
 def default_netrc_username() -> str:
     return "username"
@@ -382,9 +428,21 @@ def teardown_cached_dir() -> Generator[TeardownCachedDirFn, None, None]:
 
 
 @pytest.fixture(scope="session")
-def make_commit_obj() -> MakeCommitObjFn:
+def make_commit_obj(
+    commit_author: Actor, stable_now_date: GetStableDateNowFn
+) -> MakeCommitObjFn:
     def _make_commit(message: str) -> Commit:
-        return Commit(repo=Repo(), binsha=Commit.NULL_BIN_SHA, message=message)
+        commit_timestamp = round(stable_now_date().timestamp())
+        return Commit(
+            repo=Repo(),
+            binsha=Commit.NULL_BIN_SHA,
+            message=message,
+            author=commit_author,
+            authored_date=commit_timestamp,
+            committer=commit_author,
+            committed_date=commit_timestamp,
+            parents=[],
+        )
 
     return _make_commit
 
