@@ -5,22 +5,23 @@ from typing import TYPE_CHECKING
 import pytest
 from pytest_lazy_fixtures.lazy_fixture import lf as lazy_fixture
 
-from semantic_release.cli.commands.main import main
+from semantic_release.hvcs.github import Github
 
 from tests.const import (
     MAIN_PROG_NAME,
     VERSION_SUBCMD,
 )
-from tests.fixtures.commit_parsers import angular_minor_commits
-from tests.fixtures.git_repo import get_commit_def_of_angular_commit
+from tests.fixtures.commit_parsers import conventional_minor_commits
+from tests.fixtures.git_repo import get_commit_def_of_conventional_commit
 from tests.fixtures.repos import (
-    repo_w_git_flow_w_rc_n_alpha_prereleases_n_angular_commits_using_tag_format,
-    repo_w_no_tags_angular_commits,
-    repo_w_trunk_only_angular_commits,
-    repo_w_trunk_only_angular_commits_using_tag_format,
+    repo_w_git_flow_w_rc_n_alpha_prereleases_n_conventional_commits_using_tag_format,
+    repo_w_no_tags_conventional_commits,
+    repo_w_trunk_only_conventional_commits,
+    repo_w_trunk_only_conventional_commits_using_tag_format,
 )
 from tests.fixtures.repos.trunk_based_dev.repo_w_no_tags import (
-    repo_w_no_tags_angular_commits_using_tag_format,
+    repo_w_no_tags_conventional_commits_using_tag_format,
+    repo_w_no_tags_conventional_commits_w_zero_version,
 )
 from tests.util import (
     add_text_to_file,
@@ -31,9 +32,9 @@ from tests.util import (
 if TYPE_CHECKING:
     from unittest.mock import MagicMock
 
-    from click.testing import CliRunner
     from requests_mock import Mocker
 
+    from tests.conftest import RunCliFn
     from tests.fixtures.git_repo import (
         BuiltRepoResult,
         GetCfgValueFromDefFn,
@@ -47,8 +48,8 @@ if TYPE_CHECKING:
     "repo_result, commits, force_args, next_release_version",
     [
         (
-            lazy_fixture(repo_w_trunk_only_angular_commits.__name__),
-            lazy_fixture(angular_minor_commits.__name__),
+            lazy_fixture(repo_w_trunk_only_conventional_commits.__name__),
+            lazy_fixture(conventional_minor_commits.__name__),
             cli_args,
             next_release_version,
         )
@@ -96,7 +97,7 @@ def test_version_print_next_version(
     force_args: list[str],
     next_release_version: str,
     file_in_repo: str,
-    cli_runner: CliRunner,
+    run_cli: RunCliFn,
     mocked_git_push: MagicMock,
     post_mocker: Mocker,
 ):
@@ -128,7 +129,7 @@ def test_version_print_next_version(
 
     # Act
     cli_cmd = [MAIN_PROG_NAME, VERSION_SUBCMD, "--print", *force_args]
-    result = cli_runner.invoke(main, cli_cmd[1:])
+    result = run_cli(cli_cmd[1:], env={Github.DEFAULT_ENV_TOKEN_NAME: "1234"})
 
     # take measurement after running the version command
     repo_status_after = repo.git.status(short=True)
@@ -138,7 +139,6 @@ def test_version_print_next_version(
 
     # Evaluate
     assert_successful_exit_code(result, cli_cmd)
-    assert not result.stderr
     assert f"{next_release_version}\n" == result.stdout
 
     # assert nothing else happened (no code changes, no commit, no tag, no push, no vcs release)
@@ -155,15 +155,15 @@ def test_version_print_next_version(
         *[
             pytest.param(
                 lazy_fixture(repo_fixture_name),
-                lazy_fixture(angular_minor_commits.__name__),
+                lazy_fixture(conventional_minor_commits.__name__),
                 cli_args,
                 next_release_version,
                 marks=marks if marks else [],
             )
             for repo_fixture_name, marks in (
-                (repo_w_trunk_only_angular_commits.__name__, None),
+                (repo_w_trunk_only_conventional_commits.__name__, None),
                 (
-                    repo_w_trunk_only_angular_commits_using_tag_format.__name__,
+                    repo_w_trunk_only_conventional_commits_using_tag_format.__name__,
                     pytest.mark.comprehensive,
                 ),
             )
@@ -213,8 +213,7 @@ def test_version_print_next_version(
                 marks=pytest.mark.comprehensive,
             )
             for repo_fixture_name in (
-                repo_w_no_tags_angular_commits.__name__,
-                repo_w_no_tags_angular_commits_using_tag_format.__name__,
+                repo_w_no_tags_conventional_commits_w_zero_version.__name__,
             )
             for cli_args, next_release_version in (
                 # Dynamic version bump determination (based on commits)
@@ -262,7 +261,7 @@ def test_version_print_tag_prints_next_tag(
     next_release_version: str,
     get_cfg_value_from_def: GetCfgValueFromDefFn,
     file_in_repo: str,
-    cli_runner: CliRunner,
+    run_cli: RunCliFn,
     mocked_git_push: MagicMock,
     post_mocker: Mocker,
 ):
@@ -298,7 +297,122 @@ def test_version_print_tag_prints_next_tag(
 
     # Act
     cli_cmd = [MAIN_PROG_NAME, VERSION_SUBCMD, "--print-tag", *force_args]
-    result = cli_runner.invoke(main, cli_cmd[1:])
+    result = run_cli(cli_cmd[1:], env={Github.DEFAULT_ENV_TOKEN_NAME: "1234"})
+
+    # take measurement after running the version command
+    repo_status_after = repo.git.status(short=True)
+    head_after = repo.head.commit.hexsha
+    tags_after = {tag.name for tag in repo.tags}
+    tags_set_difference = set.difference(tags_after, tags_before)
+
+    # Evaluate
+    assert_successful_exit_code(result, cli_cmd)
+    assert f"{next_release_tag}\n" == result.stdout
+
+    # assert nothing else happened (no code changes, no commit, no tag, no push, no vcs release)
+    assert repo_status_before == repo_status_after
+    assert head_before == head_after
+    assert not tags_set_difference
+    assert mocked_git_push.call_count == 0
+    assert post_mocker.call_count == 0
+
+
+@pytest.mark.parametrize(
+    "repo_result, commits, force_args, next_release_version",
+    [
+        pytest.param(
+            lazy_fixture(repo_fixture_name),
+            [],
+            cli_args,
+            next_release_version,
+            marks=pytest.mark.comprehensive,
+        )
+        for repo_fixture_name in (
+            repo_w_no_tags_conventional_commits.__name__,
+            repo_w_no_tags_conventional_commits_using_tag_format.__name__,
+        )
+        for cli_args, next_release_version in (
+            # Dynamic version bump determination (based on commits)
+            ([], "1.0.0"),
+            # Dynamic version bump determination (based on commits) with build metadata
+            (["--build-metadata", "build.12345"], "1.0.0+build.12345"),
+            # Forced version bump
+            (["--prerelease"], "0.0.0-rc.1"),
+            (["--patch"], "0.0.1"),
+            (["--minor"], "0.1.0"),
+            (["--major"], "1.0.0"),
+            # Forced version bump with --build-metadata
+            (["--patch", "--build-metadata", "build.12345"], "0.0.1+build.12345"),
+            # Forced version bump with --as-prerelease
+            (["--prerelease", "--as-prerelease"], "0.0.0-rc.1"),
+            (["--patch", "--as-prerelease"], "0.0.1-rc.1"),
+            (["--minor", "--as-prerelease"], "0.1.0-rc.1"),
+            (["--major", "--as-prerelease"], "1.0.0-rc.1"),
+            # Forced version bump with --as-prerelease and modified --prerelease-token
+            (
+                ["--patch", "--as-prerelease", "--prerelease-token", "beta"],
+                "0.0.1-beta.1",
+            ),
+            # Forced version bump with --as-prerelease and modified --prerelease-token
+            # and --build-metadata
+            (
+                [
+                    "--patch",
+                    "--as-prerelease",
+                    "--prerelease-token",
+                    "beta",
+                    "--build-metadata",
+                    "build.12345",
+                ],
+                "0.0.1-beta.1+build.12345",
+            ),
+        )
+    ],
+)
+def test_version_print_tag_prints_next_tag_no_zero_versions(
+    repo_result: BuiltRepoResult,
+    commits: list[str],
+    force_args: list[str],
+    next_release_version: str,
+    get_cfg_value_from_def: GetCfgValueFromDefFn,
+    file_in_repo: str,
+    run_cli: RunCliFn,
+    mocked_git_push: MagicMock,
+    post_mocker: Mocker,
+):
+    """
+    Given a generic repository at the latest release version and a subsequent commit,
+    When running the version command with the --print-tag flag,
+    Then the expected next release tag should be printed and exit without
+    making any changes to the repository.
+
+    Note: The point of this test is to only verify that the `--print-tag` flag does not
+    make any changes to the repository--not to validate if the next version is calculated
+    correctly per the repository structure (see test_version_release &
+    test_version_force_level for correctness).
+
+    However, we do validate that --print-tag & a force option and/or --as-prerelease options
+    work together to print the next release tag correctly but not make a change to the repo.
+    """
+    repo = repo_result["repo"]
+    repo_def = repo_result["definition"]
+    tag_format_str: str = get_cfg_value_from_def(repo_def, "tag_format_str")  # type: ignore[assignment]
+    next_release_tag = tag_format_str.format(version=next_release_version)
+
+    if len(commits) > 1:
+        # Make a commit to ensure we have something to release
+        # otherwise the "no release will be made" logic will kick in first
+        add_text_to_file(repo, file_in_repo)
+        repo.git.commit(m=commits[-1], a=True)
+
+    # Setup: take measurement before running the version command
+    repo_status_before = repo.git.status(short=True)
+    head_before = repo.head.commit.hexsha
+    tags_before = {tag.name for tag in repo.tags}
+
+    # Act
+    cli_cmd = [MAIN_PROG_NAME, VERSION_SUBCMD, "--print-tag", *force_args]
+    result = run_cli(cli_cmd[1:], env={Github.DEFAULT_ENV_TOKEN_NAME: "1234"})
 
     # take measurement after running the version command
     repo_status_after = repo.git.status(short=True)
@@ -308,7 +422,6 @@ def test_version_print_tag_prints_next_tag(
 
     # Evaluate
     assert_successful_exit_code(result, cli_cmd)
-    assert not result.stderr
     assert f"{next_release_tag}\n" == result.stdout
 
     # assert nothing else happened (no code changes, no commit, no tag, no push, no vcs release)
@@ -321,12 +434,12 @@ def test_version_print_tag_prints_next_tag(
 
 @pytest.mark.parametrize(
     "repo_result",
-    [lazy_fixture(repo_w_trunk_only_angular_commits.__name__)],
+    [lazy_fixture(repo_w_trunk_only_conventional_commits.__name__)],
 )
 def test_version_print_last_released_prints_version(
     repo_result: BuiltRepoResult,
     get_versions_from_repo_build_def: GetVersionsFromRepoBuildDefFn,
-    cli_runner: CliRunner,
+    run_cli: RunCliFn,
     mocked_git_push: MagicMock,
     post_mocker: Mocker,
 ):
@@ -342,7 +455,7 @@ def test_version_print_last_released_prints_version(
 
     # Act
     cli_cmd = [MAIN_PROG_NAME, VERSION_SUBCMD, "--print-last-released"]
-    result = cli_runner.invoke(main, cli_cmd[1:])
+    result = run_cli(cli_cmd[1:], env={Github.DEFAULT_ENV_TOKEN_NAME: "1234"})
 
     # take measurement after running the version command
     repo_status_after = repo.git.status(short=True)
@@ -367,8 +480,8 @@ def test_version_print_last_released_prints_version(
     "repo_result, commits",
     [
         (
-            lazy_fixture(repo_w_trunk_only_angular_commits.__name__),
-            lazy_fixture(angular_minor_commits.__name__),
+            lazy_fixture(repo_w_trunk_only_conventional_commits.__name__),
+            lazy_fixture(conventional_minor_commits.__name__),
         )
     ],
 )
@@ -376,7 +489,7 @@ def test_version_print_last_released_prints_released_if_commits(
     repo_result: BuiltRepoResult,
     get_versions_from_repo_build_def: GetVersionsFromRepoBuildDefFn,
     commits: list[str],
-    cli_runner: CliRunner,
+    run_cli: RunCliFn,
     mocked_git_push: MagicMock,
     post_mocker: Mocker,
     file_in_repo: str,
@@ -397,7 +510,7 @@ def test_version_print_last_released_prints_released_if_commits(
 
     # Act
     cli_cmd = [MAIN_PROG_NAME, VERSION_SUBCMD, "--print-last-released"]
-    result = cli_runner.invoke(main, cli_cmd[1:])
+    result = run_cli(cli_cmd[1:])
 
     # take measurement after running the version command
     repo_status_after = repo.git.status(short=True)
@@ -420,11 +533,11 @@ def test_version_print_last_released_prints_released_if_commits(
 
 @pytest.mark.parametrize(
     "repo_result",
-    [lazy_fixture(repo_w_no_tags_angular_commits.__name__)],
+    [lazy_fixture(repo_w_no_tags_conventional_commits.__name__)],
 )
 def test_version_print_last_released_prints_nothing_if_no_tags(
     repo_result: BuiltRepoResult,
-    cli_runner: CliRunner,
+    run_cli: RunCliFn,
     mocked_git_push: MagicMock,
     post_mocker: Mocker,
     caplog: pytest.LogCaptureFixture,
@@ -438,7 +551,7 @@ def test_version_print_last_released_prints_nothing_if_no_tags(
 
     # Act
     cli_cmd = [MAIN_PROG_NAME, VERSION_SUBCMD, "--print-last-released"]
-    result = cli_runner.invoke(main, cli_cmd[1:])
+    result = run_cli(cli_cmd[1:])
 
     # take measurement after running the version command
     repo_status_after = repo.git.status(short=True)
@@ -464,12 +577,12 @@ def test_version_print_last_released_prints_nothing_if_no_tags(
 
 @pytest.mark.parametrize(
     "repo_result",
-    [lazy_fixture(repo_w_trunk_only_angular_commits.__name__)],
+    [lazy_fixture(repo_w_trunk_only_conventional_commits.__name__)],
 )
 def test_version_print_last_released_on_detached_head(
     repo_result: BuiltRepoResult,
     get_versions_from_repo_build_def: GetVersionsFromRepoBuildDefFn,
-    cli_runner: CliRunner,
+    run_cli: RunCliFn,
     mocked_git_push: MagicMock,
     post_mocker: Mocker,
 ):
@@ -488,7 +601,7 @@ def test_version_print_last_released_on_detached_head(
 
     # Act
     cli_cmd = [MAIN_PROG_NAME, VERSION_SUBCMD, "--print-last-released"]
-    result = cli_runner.invoke(main, cli_cmd[1:])
+    result = run_cli(cli_cmd[1:])
 
     # take measurement after running the version command
     repo_status_after = repo.git.status(short=True)
@@ -511,12 +624,12 @@ def test_version_print_last_released_on_detached_head(
 
 @pytest.mark.parametrize(
     "repo_result",
-    [lazy_fixture(repo_w_trunk_only_angular_commits.__name__)],
+    [lazy_fixture(repo_w_trunk_only_conventional_commits.__name__)],
 )
 def test_version_print_last_released_on_nonrelease_branch(
     repo_result: BuiltRepoResult,
     get_versions_from_repo_build_def: GetVersionsFromRepoBuildDefFn,
-    cli_runner: CliRunner,
+    run_cli: RunCliFn,
     mocked_git_push: MagicMock,
     post_mocker: Mocker,
 ):
@@ -535,7 +648,7 @@ def test_version_print_last_released_on_nonrelease_branch(
 
     # Act
     cli_cmd = [MAIN_PROG_NAME, VERSION_SUBCMD, "--print-last-released"]
-    result = cli_runner.invoke(main, cli_cmd[1:])
+    result = run_cli(cli_cmd[1:])
 
     # take measurement after running the version command
     repo_status_after = repo.git.status(short=True)
@@ -559,10 +672,10 @@ def test_version_print_last_released_on_nonrelease_branch(
 @pytest.mark.parametrize(
     "repo_result",
     [
-        lazy_fixture(repo_w_trunk_only_angular_commits.__name__),
+        lazy_fixture(repo_w_trunk_only_conventional_commits.__name__),
         pytest.param(
             lazy_fixture(
-                repo_w_git_flow_w_rc_n_alpha_prereleases_n_angular_commits_using_tag_format.__name__
+                repo_w_git_flow_w_rc_n_alpha_prereleases_n_conventional_commits_using_tag_format.__name__
             ),
             marks=pytest.mark.comprehensive,
         ),
@@ -572,7 +685,7 @@ def test_version_print_last_released_tag_prints_correct_tag(
     repo_result: BuiltRepoResult,
     get_cfg_value_from_def: GetCfgValueFromDefFn,
     get_versions_from_repo_build_def: GetVersionsFromRepoBuildDefFn,
-    cli_runner: CliRunner,
+    run_cli: RunCliFn,
     mocked_git_push: MagicMock,
     post_mocker: Mocker,
 ):
@@ -589,7 +702,7 @@ def test_version_print_last_released_tag_prints_correct_tag(
 
     # Act
     cli_cmd = [MAIN_PROG_NAME, VERSION_SUBCMD, "--print-last-released-tag"]
-    result = cli_runner.invoke(main, cli_cmd[1:])
+    result = run_cli(cli_cmd[1:])
 
     # take measurement after running the version command
     repo_status_after = repo.git.status(short=True)
@@ -614,14 +727,14 @@ def test_version_print_last_released_tag_prints_correct_tag(
     "repo_result, commits",
     [
         (
-            lazy_fixture(repo_w_trunk_only_angular_commits.__name__),
-            lazy_fixture(angular_minor_commits.__name__),
+            lazy_fixture(repo_w_trunk_only_conventional_commits.__name__),
+            lazy_fixture(conventional_minor_commits.__name__),
         ),
         pytest.param(
             lazy_fixture(
-                repo_w_git_flow_w_rc_n_alpha_prereleases_n_angular_commits_using_tag_format.__name__
+                repo_w_git_flow_w_rc_n_alpha_prereleases_n_conventional_commits_using_tag_format.__name__
             ),
-            lazy_fixture(angular_minor_commits.__name__),
+            lazy_fixture(conventional_minor_commits.__name__),
             marks=pytest.mark.comprehensive,
         ),
     ],
@@ -631,7 +744,7 @@ def test_version_print_last_released_tag_prints_released_if_commits(
     get_cfg_value_from_def: GetCfgValueFromDefFn,
     get_versions_from_repo_build_def: GetVersionsFromRepoBuildDefFn,
     commits: list[str],
-    cli_runner: CliRunner,
+    run_cli: RunCliFn,
     mocked_git_push: MagicMock,
     post_mocker: Mocker,
     file_in_repo: str,
@@ -653,7 +766,7 @@ def test_version_print_last_released_tag_prints_released_if_commits(
 
     # Act
     cli_cmd = [MAIN_PROG_NAME, VERSION_SUBCMD, "--print-last-released-tag"]
-    result = cli_runner.invoke(main, cli_cmd[1:])
+    result = run_cli(cli_cmd[1:])
 
     # take measurement after running the version command
     repo_status_after = repo.git.status(short=True)
@@ -676,11 +789,11 @@ def test_version_print_last_released_tag_prints_released_if_commits(
 
 @pytest.mark.parametrize(
     "repo_result",
-    [lazy_fixture(repo_w_no_tags_angular_commits.__name__)],
+    [lazy_fixture(repo_w_no_tags_conventional_commits.__name__)],
 )
 def test_version_print_last_released_tag_prints_nothing_if_no_tags(
     repo_result: BuiltRepoResult,
-    cli_runner: CliRunner,
+    run_cli: RunCliFn,
     mocked_git_push: MagicMock,
     post_mocker: Mocker,
     caplog: pytest.LogCaptureFixture,
@@ -694,7 +807,7 @@ def test_version_print_last_released_tag_prints_nothing_if_no_tags(
 
     # Act
     cli_cmd = [MAIN_PROG_NAME, VERSION_SUBCMD, "--print-last-released-tag"]
-    result = cli_runner.invoke(main, cli_cmd[1:])
+    result = run_cli(cli_cmd[1:])
 
     # take measurement after running the version command
     repo_status_after = repo.git.status(short=True)
@@ -721,10 +834,10 @@ def test_version_print_last_released_tag_prints_nothing_if_no_tags(
 @pytest.mark.parametrize(
     "repo_result",
     [
-        lazy_fixture(repo_w_trunk_only_angular_commits.__name__),
+        lazy_fixture(repo_w_trunk_only_conventional_commits.__name__),
         pytest.param(
             lazy_fixture(
-                repo_w_git_flow_w_rc_n_alpha_prereleases_n_angular_commits_using_tag_format.__name__
+                repo_w_git_flow_w_rc_n_alpha_prereleases_n_conventional_commits_using_tag_format.__name__
             ),
             marks=pytest.mark.comprehensive,
         ),
@@ -734,7 +847,7 @@ def test_version_print_last_released_tag_on_detached_head(
     repo_result: BuiltRepoResult,
     get_cfg_value_from_def: GetCfgValueFromDefFn,
     get_versions_from_repo_build_def: GetVersionsFromRepoBuildDefFn,
-    cli_runner: CliRunner,
+    run_cli: RunCliFn,
     mocked_git_push: MagicMock,
     post_mocker: Mocker,
 ):
@@ -754,7 +867,7 @@ def test_version_print_last_released_tag_on_detached_head(
 
     # Act
     cli_cmd = [MAIN_PROG_NAME, VERSION_SUBCMD, "--print-last-released-tag"]
-    result = cli_runner.invoke(main, cli_cmd[1:])
+    result = run_cli(cli_cmd[1:])
 
     # take measurement after running the version command
     repo_status_after = repo.git.status(short=True)
@@ -778,10 +891,10 @@ def test_version_print_last_released_tag_on_detached_head(
 @pytest.mark.parametrize(
     "repo_result",
     [
-        lazy_fixture(repo_w_trunk_only_angular_commits.__name__),
+        lazy_fixture(repo_w_trunk_only_conventional_commits.__name__),
         pytest.param(
             lazy_fixture(
-                repo_w_git_flow_w_rc_n_alpha_prereleases_n_angular_commits_using_tag_format.__name__
+                repo_w_git_flow_w_rc_n_alpha_prereleases_n_conventional_commits_using_tag_format.__name__
             ),
             marks=pytest.mark.comprehensive,
         ),
@@ -791,7 +904,7 @@ def test_version_print_last_released_tag_on_nonrelease_branch(
     repo_result: BuiltRepoResult,
     get_cfg_value_from_def: GetCfgValueFromDefFn,
     get_versions_from_repo_build_def: GetVersionsFromRepoBuildDefFn,
-    cli_runner: CliRunner,
+    run_cli: RunCliFn,
     mocked_git_push: MagicMock,
     post_mocker: Mocker,
 ):
@@ -811,7 +924,7 @@ def test_version_print_last_released_tag_on_nonrelease_branch(
 
     # Act
     cli_cmd = [MAIN_PROG_NAME, VERSION_SUBCMD, "--print-last-released-tag"]
-    result = cli_runner.invoke(main, cli_cmd[1:])
+    result = run_cli(cli_cmd[1:])
 
     # take measurement after running the version command
     repo_status_after = repo.git.status(short=True)
@@ -836,14 +949,14 @@ def test_version_print_last_released_tag_on_nonrelease_branch(
     "repo_result, get_commit_def_fn",
     [
         (
-            lazy_fixture(repo_w_trunk_only_angular_commits.__name__),
-            lazy_fixture(get_commit_def_of_angular_commit.__name__),
+            lazy_fixture(repo_w_trunk_only_conventional_commits.__name__),
+            lazy_fixture(get_commit_def_of_conventional_commit.__name__),
         )
     ],
 )
 def test_version_print_next_version_fails_on_detached_head(
     repo_result: BuiltRepoResult,
-    cli_runner: CliRunner,
+    run_cli: RunCliFn,
     simulate_change_commits_n_rtn_changelog_entry: SimulateChangeCommitsNReturnChangelogEntryFn,
     get_commit_def_fn: GetCommitDefFn,
     mocked_git_push: MagicMock,
@@ -870,7 +983,7 @@ def test_version_print_next_version_fails_on_detached_head(
 
     # Act
     cli_cmd = [MAIN_PROG_NAME, VERSION_SUBCMD, "--print"]
-    result = cli_runner.invoke(main, cli_cmd[1:])
+    result = run_cli(cli_cmd[1:])
 
     # take measurement after running the version command
     repo_status_after = repo.git.status(short=True)
@@ -895,14 +1008,14 @@ def test_version_print_next_version_fails_on_detached_head(
     "repo_result, get_commit_def_fn",
     [
         (
-            lazy_fixture(repo_w_trunk_only_angular_commits.__name__),
-            lazy_fixture(get_commit_def_of_angular_commit.__name__),
+            lazy_fixture(repo_w_trunk_only_conventional_commits.__name__),
+            lazy_fixture(get_commit_def_of_conventional_commit.__name__),
         )
     ],
 )
 def test_version_print_next_tag_fails_on_detached_head(
     repo_result: BuiltRepoResult,
-    cli_runner: CliRunner,
+    run_cli: RunCliFn,
     simulate_change_commits_n_rtn_changelog_entry: SimulateChangeCommitsNReturnChangelogEntryFn,
     get_commit_def_fn: GetCommitDefFn,
     mocked_git_push: MagicMock,
@@ -929,7 +1042,7 @@ def test_version_print_next_tag_fails_on_detached_head(
 
     # Act
     cli_cmd = [MAIN_PROG_NAME, VERSION_SUBCMD, "--print-tag"]
-    result = cli_runner.invoke(main, cli_cmd[1:])
+    result = run_cli(cli_cmd[1:])
 
     # take measurement after running the version command
     repo_status_after = repo.git.status(short=True)
